@@ -65,8 +65,6 @@ gda_mysql_cmd_new()
 void
 gda_mysql_cmd_free(Gda_MYSQL_Command* cmd)
 {
-  GList* ptr;
-  
   g_free(cmd);
 	
 }
@@ -85,13 +83,15 @@ gda_mysql_cmd_set_connection(Gda_MYSQL_Command* cmd,
 Gda_MYSQL_Recordset*
 gda_mysql_cmd_execute(Gda_MYSQL_Command* cmd, gulong options)
 {
-  gint                rc;
-  
-#if 0
-  rc = mysql_real_query(cmd->cnc->mysql, cmd->cmd, cmd->cmd_length);
+  gint rc;
+
+  fprintf(stderr,"gda_mysql_cmd_execute called\n");
+  fprintf(stderr,"gda_mysql_cmd_execute: cmd = '%p'\n", cmd);
+  fprintf(stderr,"gda_mysql_cmd_execute: cmd->cmd = '%s'\n", cmd->cmd);
+  fprintf(stderr,"*** Calling mysql_real_query\n");
+  rc = mysql_real_query(cmd->cnc->mysql, cmd->cmd, strlen(cmd->cmd));
   fprintf(stderr,"gda_cmd_execute: rc = %d\n", rc);
   fprintf(stderr,"                 mysql errno = %d\n",  mysql_errno(cmd->cnc->mysql));
   fprintf(stderr,"                 mysql errmsg = '%s'\n", mysql_error(cmd->cnc->mysql));
-#endif
   return 0;
 }
