@@ -1,6 +1,7 @@
 #include <stdio.h>
 #include <string.h>
 #include <ctype.h>
+#include <stdlib.h>
 
 #include <mysql/mysql.h>
 #include <glib.h>
@@ -80,9 +81,9 @@ get_value(gchar* ptr)
 
 gint
 gda_mysql_connection_open(Gda_MYSQL_Connection* cnc,
-			  gchar*          cnc_string,
-			  gchar*          user,
-			  gchar*          passwd)
+			  const gchar*          cnc_string,
+			  const gchar*          user,
+			  const gchar*          passwd)
 {
   gchar* ptr_s;
   gchar* ptr_e;
@@ -112,13 +113,15 @@ gda_mysql_connection_open(Gda_MYSQL_Connection* cnc,
     }
   cnc->mysql = g_new0(MYSQL, 1);
   fprintf(stderr,"cnc->mysql = %p\n", cnc->mysql);
+  fprintf(stderr,"** Calling mysql_real_connect\n");
   rc = mysql_real_connect(cnc->mysql, cnc->host,
 			  cnc->user,
 			  cnc->password,
 			  cnc->port ? atoi(cnc->port) : 0,
 			  cnc->unix_socket,
 			  cnc->flags ? atoi(cnc->flags) : 0);
-  fprintf(stderr,"cnc->mys	ql after connect = %p\n", cnc->mysql);
+
+  fprintf(stderr,"cnc->mysql after connect = %p\n", cnc->mysql);
   
   if (!rc)
     {
@@ -127,7 +130,11 @@ gda_mysql_connection_open(Gda_MYSQL_Connection* cnc,
 	      mysql_error(cnc->mysql));
       return -1;
     }
+  fprintf(stderr,"before mysql_select_db: cnc->db = '%s'\n", cnc->db);
+  fprintf(stderr,"cnc->mysql = %p\n", cnc->mysql);
+  fprintf(stderr,"*** Calling mysql_select_db\n");
   err = mysql_select_db(cnc->mysql, cnc->db);
+  fprintf(stderr,"mysql_select_db returns %d\n", err);
   if (err != 0)
     {
       fprintf(stderr,"mysql errno  = %d\n",mysql_errno(cnc->mysql));
@@ -135,13 +142,14 @@ gda_mysql_connection_open(Gda_MYSQL_Connection* cnc,
 	      mysql_error(cnc->mysql));
       return -1;
     }
-  
+  fprintf(stderr,"gda_mysql_connection_open: returning\n");
   return 0;
 }
 
 gint
 gda_mysql_connection_close(Gda_MYSQL_Connection* c)
 {
+  fprintf(stderr,"Calling mysql_close\n");
   mysql_close(c->mysql);
   return 0;
 }
