@@ -50,8 +50,8 @@ gda_odbc_recset_free(Gda_ODBC_Recordset* recset)
 
 
 
-static GDA_ValueType
-sqltype_2_gda_type(gint sql_type)
+GDA_ValueType
+gda_odbc_sql2gdatype(gint sql_type)
 {
   switch (sql_type)
     {
@@ -97,6 +97,54 @@ sqltype_2_gda_type(gint sql_type)
     }
 }
 
+gint
+gda_odbc_sql2ctype(gint sql_type)
+{
+  switch (sql_type)
+    {
+    case SQL_BIT:
+      return SQL_C_BIT;
+    case SQL_BIGINT:
+      return SQL_C_CHAR;
+    case SQL_SMALLINT:
+      return SQL_C_SSHORT;
+    case SQL_TINYINT:
+      return SQL_C_STINYINT;
+    case SQL_INTEGER:
+      return SQL_C_SLONG;
+    case SQL_CHAR:
+      return SQL_C_CHAR;
+    case SQL_VARCHAR:
+      return SQL_C_CHAR;
+    case SQL_VARBINARY:
+      return SQL_C_BINARY;
+    case SQL_BINARY:
+      return SQL_C_BINARY;
+    case SQL_LONGVARBINARY:
+      return SQL_C_BINARY;
+    case SQL_LONGVARCHAR:
+      return SQL_C_CHAR;
+    case SQL_DECIMAL:
+      return SQL_C_CHAR;
+    case SQL_NUMERIC:
+      return SQL_C_CHAR;
+    case SQL_REAL:
+      return SQL_C_FLOAT;
+    case SQL_DOUBLE:
+      return SQL_C_DOUBLE;
+    case SQL_FLOAT:
+      return SQL_C_DOUBLE;
+    case SQL_DATE:
+      return SQL_C_DATE;
+    case SQL_TIME:
+      return SQL_C_TIME;
+    case SQL_TIMESTAMP:
+      return SQL_C_TIMESTAMP;
+    default:
+      return GDA_TypeNull;
+    }
+}
+
 static gint
 allocate_recordset_memory(Gda_ODBC_Recordset* rec)
 {
@@ -119,14 +167,14 @@ allocate_recordset_memory(Gda_ODBC_Recordset* rec)
 	  return -1;
 	}
 
-      fprintf(stderr,"allocate_recordset_memory: server_field->ll_type = %d\n",
-	      server_field->ll_type);
+      printf("allocate_recordset_memory: server_field->sql_type = %d\n",
+	     server_field->sql_type);
       
-      server_field->value->_d = sqltype_2_gda_type(server_field->ll_type);
-      fprintf(stderr,"allocate_recordset_memory: server_field->value->_d at %p = %d\n",
-	      &server_field->value->_d,server_field->value->_d);
+      server_field->value->_d = gda_odbc_sql2gdatype(server_field->sql_type);
+      printf("allocate_recordset_memory: server_field->value->_d at %p = %d\n",
+	     &server_field->value->_d,server_field->value->_d);
 
-      server_field->c_type = gda_odbc_gda2sqlctype(server_field->value->_d);
+      server_field->c_type = gda_odbc_sql2ctype(server_field->sql_type);
       
       switch (server_field->c_type)
 	{
@@ -135,17 +183,29 @@ allocate_recordset_memory(Gda_ODBC_Recordset* rec)
 	   * GDA_TypeLongvarchar, GDA_TypeLongvarwchar,
 	   * GDA_TypeNumeric, GDA_TypeUBigInt, GDA_TypeVarchar,
 	   * GDA_TypeVarwchar, GDA_TypeFixchar, GDA_TypeFixbin,
-	   * GDA_TypeFixwchar
+	   * GDA_TypeFixwchar, GDA_TypeChar
 	   */
 	case SQL_C_CHAR:	/* unsigned gchar* (zero terminated)*/
-	  fprintf(stderr,"allocate_field: SQL_C_CHAR\n");
-	  server_field->value->_u.lvc = CORBA_string_alloc(server_field->defined_length + 1);
+	  printf("allocate_field '%s': SQL_C_CHAR, defined_length = %ld \n",
+		 server_field->name, server_field->defined_length);
+	  /* Various SQL (GDA) types are mapped to SQL_C_CHAR for retrieval.
+	     Be smart about allocating storage.
+	     SQL_LONGVARCHAR and SQL_LONGVARBINARY get allocated 255 bytes of data.
+	     If that's enough, find. Otherwise the client must use the get_chunk
+	     method to retrieve the data used for (BLOBS).
+	  */
+	  if (server_field->sql_type == SQL_LONGVARBINARY
+	      || server_field->sql_type == SQL_LONGVARCHAR)
+	    server_field->value->_u.lvc = CORBA_string_alloc(256);
+	  else
+	    server_field->value->_u.lvc = CORBA_string_alloc(server_field->defined_length + 1);
 	  server_field->malloced      = 1;
 	  rc = SQLBindCol(rec->hstmt,
 			  i + 1,
 			  server_field->c_type,
 			  server_field->value->_u.lvc,
-			  server_field->defined_length,
+			  server_field->sql_type == SQL_LONGVARBINARY || server_field->sql_type == SQL_LONGVARCHAR ?
+			  255 : server_field->defined_length + 1, /* add 1 for zero termination */
 			  &server_field->actual_length);
 	  if (rc != 0)
 	    goto bad_binding;
@@ -233,7 +293,7 @@ allocate_recordset_memory(Gda_ODBC_Recordset* rec)
 	   * GDA_TypeLongvarbin
 	   */
 	case SQL_C_BINARY:	/* unsigned gchar* (with length) */
-	  fprintf(stderr,"SQL_C_BINARY found\n");
+	  printf("SQL_C_BINARY found\n");
 	  server_field->value->_u.lvb._buffer = CORBA_string_alloc(server_field->defined_length);
 	  server_field->value->_u.lvb._maximum = server_field->defined_length;
 	  server_field->malloced      = 1;
@@ -363,11 +423,11 @@ gda_odbc_recset_move_prev(Gda_ODBC_Recordset* recset)
     {
       Gda_ODBC_Field* f = l->data;
       
-      if (f->ll_type == SQL_VARCHAR && f->value->_u.lvc)
+      if (f->sql_type == SQL_VARCHAR && f->value->_u.lvc)
 	{
 	  memset(f->value->_u.lvc, 0, f->defined_length);
 	}
-      else if (f->ll_type == SQL_CHAR && f->defined_length > 1 && f->value->_u.lvc)
+      else if (f->sql_type == SQL_CHAR && f->defined_length > 1 && f->value->_u.lvc)
 	{
 	  memset(f->value->_u.lvc,' ', f->defined_length);
 	}
